Release notes for AUCTeX 13.2 with preview-latex
================================================

AUCTeX provides by far the most wide-spread and sophisticated
environment for editing LaTeX, TeX, ConTeXt and Texinfo documents with
Emacs.  Combined with packages like RefTeX, flyspell and others it is
pretty much without peer as a comprehensive authoring solution for a
large variety of operating system platforms and TeX distributions.  It
supports document-dependent completion and syntax highlighting, easily
accessible menus, jumping to error locations in the source file, a
number of editing shortcuts, intelligent indentation and filling of
text during entry, and WYSIWYG previews of graphical elements like
math formulas right in the Emacs source buffer, by virtue of its
preview-latex component.

One part of the preview-latex subsystem is the central `preview.sty'
file that is independently useful for a number of applications and is
available in unbundled form from CTAN.[1]

AUCTeX needs volunteers in particular for non-programming tasks:
documentation writing, tutorials, translations, reference material,
sleuth work, testing.

New features and fixed bugs in this release
-------------------------------------------

AUCTeX no longer refuses to insert dollar sign when you type ‘$’ at
point where AUCTeX thinks the current math mode didn’t start with
dollar(s).  AUCTeX assumes the user knows that it isn’t in math
mode actually.

You can keep the former behavior by enabling the new customize
option ‘TeX-refuse-unmatched-dollar’.

AUCTeX supports completion-at-point of macro and environment
arguments in LaTeX buffers.  The responsible function recognizes
the argument position and extracts the corresponding candidates
from the variables ‘TeX-symbol-list’ and ‘LaTeX-environment-list’.

AUCTeX underlines the argument of macros which produce underlined
text in the final product with ‘font-latex-underline-face’.  The
corresponding keyword class is called ‘underline-command’.  See the
section for fontification of macros if you dislike this feature and
wish to deactivate it.

Support for the Sioyek document viewer is added.

AUCTeX now requires GNU Emacs 25.1 or higher.

AUCTeX tracks the change in Emacs where initial inputs in the
minibuffer during queries are getting phased out.  Queries for the
mandatory arguments of macros and environments are adjusted where
applicable.  The value which will be used after hitting ‘RET’
without other input is shown in the prompt in parentheses prefixed
with ‘default’.  For this change the signature of the function
‘TeX-arg-length’ is altered.  The old argument list was:
     (defun TeX-arg-length (optional &optional prompt
                                     initial-input definition default)

whereas the new one is:
     (defun TeX-arg-length (optional &optional prompt
                                     default initial-input definition)

Note the position change of ‘DEFAULT’.

Indenting of conditionals is improved.  Code inside constructs like
‘\ifx . \else . \fi’ is correctly indented.  An interface for style
files is also introduced which can add their macros to the
indentation engine.  Check the file ‘algpseudocode.el’ for an
example.

You can optionally enable indent inside square brackets ‘[]’ by new
user options ‘TeX-indent-open-delimiters’ and
‘TeX-indent-close-delimiters’.

Now ‘tex-buf.el’ is merged into ‘tex.el’ and no longer exists.  If
your personal code has ‘(require 'tex-buf)’, one of the following
prescriptions would serve.
  1. Remove ‘(require 'tex-buf)’.
  2. Replace it with ‘(require 'tex)’.
  3. Replace it with ‘(require 'latex)’.

When you edit a document divided into multiple files, auto parsed
information for all sub files are saved under ‘auto’ subdirectory
at master directory when ‘TeX-parse-self’ and ‘TeX-auto-save’
options are enabled.  Now you can have support ‘.el’ file saved
under ‘auto’ subdirectory of each directory of the sub file when
the sub files aren’t located at the master directory.

To achieve that, set new user option ‘TeX-auto-save-aggregate’ to
‘nil’.

There was another hook where former dynamic free variables could be
used.  The usage was invalidated at version 13.1, by introduction
of lexical binding over AUCTeX.

The functions in ‘TeX-region-hook’ could access the free variables
‘master-buffer’ and ‘orig-buffer’.  Those are now named
‘TeX-region-master-buffer’ and ‘TeX-region-orig-buffer’,
respectively.

Requirements
------------

It is required that you use at least GNU Emacs 25.1.

The preview-latex subsystem requires image support.

You'll also need a working LaTeX installation and Ghostscript.
dvipng[2] (version 1.4 or later), a very fast DVI converter, can be
used to speed up the conversion.

Availability
------------

The easiest way for getting AUCTeX is installing it with GNU ELPA, see
<URL:https://elpa.gnu.org/packages/auctex.html> for more information.
Other download options are available at
<URL:https://ftp.gnu.org/gnu/auctex/>.  At release time, we provide the
source tarball.  You can also use versions of Emacs that already
include AUCTeX or a software package management system for your
operating system which provides you with the latest release.

A separate directory for each release contains some stuff from the
tarball, such as ChangeLog, printable manuals, and a reference sheet.
The download area is mirrored to the directory support/auctex on CTAN.
AUCTeX is licensed under the GNU General Public License version 3.

You'll find more information at the web site of AUCTeX
<URL:https://www.gnu.org/software/auctex/>, including its mailing list
addresses.

Future development and additional information
---------------------------------------------

AUCTeX is proceeding as a GNU project with the long-term intent of
merging it into Emacs.  For that reason, all new contributors need to
assign copyright to their contributions to the FSF (the usual
procedure for Emacs contributors).  The same holds for past
contributors.  The principal authors and maintainers have already done
so, but it would require a diligent and diplomatic volunteer to find
and ask the rest.

Current AUCTeX managers are Arash Esbati, Mosè Giordano, and Tassilo
Horn.  Everybody is welcome to contribute to the project by reporting
bugs and suggesting improvements, but the most effective way of
helping AUCTeX development remains volunteering for tasks.

The following people contributed to this release series (in
alphabetical order): Ivan Andrus, Ralf Angeli, Masayuki Ataka,
Mohammad Hossein Bateni, Fabrice Ben Hamouda, Thomas Baumann, Vincent
Belaïche, Berend de Boer, Alex Branham, Uwe Brauer, Ken Brown, Joshua
Buhl, Jean-François Burnol, Patrice Dumas, Arash Esbati, Werner Fink,
Miguel Frasson, Peter S. Galbraith, Mosè Giordano, Andrea Greselin,
Patrick Gundlach, Abdul-Lateef Haji-Ali, Jobst Hoffmann, Tassilo Horn,
Yvon Hevel, Orlando Iovino, Mads Jensen, Arne Jørgensen, Philip
Kaludercic, David Kastrup, Ikumi Keita, Philip Kime, Oleh Krehel,
Joost Kremers, Frank Küster, Jan-Åke Larsson, Matthew Leach, Brian
Leung, Antoine Levitt, Leo Liu, Vladimir Lomov, Stefan Monnier, Dan
Nicolaescu, Piet van Oostrum, Pieter Pareit, Nicolas Richard, Augusto
Ritter Stoffel, Florent Rougon, Santiago Saavedra, Davide
G. M. Salvetti, Rüdiger Sonderfeld, Holger Sparr, Mike Sperber, Reiner
Steib, Christian Schlauer, Shiro Takeda, Mark Trettin (Please accept
our apologies if we forgot somebody.)

Footnotes:

[1]  <URL:https://www.ctan.org/pkg/preview>

[2]  dvipng is available via its project page
<URL:https://savannah.nongnu.org/projects/dvipng> and from CTAN.
